[前][次][番号順一覧][スレッド一覧]

ruby-changes:14667

From: mame <ko1@a...>
Date: Sun, 31 Jan 2010 15:57:46 +0900 (JST)
Subject: [ruby-changes:14667] Ruby:r26518 (trunk): * lib/rexml/text.rb (REXML::Text#initialize): fix typo and a bug that

mame	2010-01-31 15:55:17 +0900 (Sun, 31 Jan 2010)

  New Revision: 26518

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=26518

  Log:
    * lib/rexml/text.rb (REXML::Text#initialize): fix typo and a bug that
      seems to be caused by refactoring.

  Modified files:
    trunk/ChangeLog
    trunk/lib/rexml/text.rb

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 26517)
+++ ChangeLog	(revision 26518)
@@ -1,3 +1,8 @@
+Sun Jan 31 15:50:34 2010  Yusuke Endoh  <mame@t...>
+
+	* lib/rexml/text.rb (REXML::Text#initialize): fix typo and a bug that
+	  seems to be caused by refactoring.
+
 Sun Jan 31 15:46:37 2010  Yusuke Endoh  <mame@t...>
 
 	* lib/rexml/parent.rb (REXML::Parent#delete): return the deleted node
@@ -2,3 +7,3 @@
 	  because the rdoc of REXML::Element#delete_element says it returns
-	  "the element that was removed."
+	  "the element that was removed."  [REXMLTracker#161]
 
Index: lib/rexml/text.rb
===================================================================
--- lib/rexml/text.rb	(revision 26517)
+++ lib/rexml/text.rb	(revision 26518)
@@ -88,7 +88,7 @@
     #   Text.new( "sean russell", false, nil, true, ["s"] ) #-> "sean russell"
     # In the last example, the +entity_filter+ argument is ignored.
     #
     # +pattern+ INTERNAL USE ONLY
     def initialize(arg, respect_whitespace=false, parent=nil, raw=nil,
       entity_filter=nil, illegal=NEEDS_A_SECOND_CHECK )
 
@@ -117,7 +117,7 @@
 
       @string.gsub!( /\r\n?/, "\n" )
 
-      Text.check(@string, NEEDS_A_SECOND_CHECK, doctype) if @raw and @parent
+      Text.check(@string, illegal, doctype) if @raw
     end
 
     def parent= parent
@@ -88,7 +88,7 @@
     # In the last example, the +entity_filter+ argument is ignored.
     #
-    # +pattern+ INTERNAL USE ONLY
+    # +illegal+ INTERNAL USE ONLY
     def initialize(arg, respect_whitespace=false, parent=nil, raw=nil,
       entity_filter=nil, illegal=NEEDS_A_SECOND_CHECK )

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]